# -*- coding: iso-8859-1 -*-
# vim: set ft=python ts=3 sw=3 expandtab:
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
#              C E D A R
#          S O L U T I O N S       "Software done right."
#           S O F T W A R E
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
# Author   : Kenneth J. Pronovici <pronovic@ieee.org>
# Language : Python 3 (>= 3.4)
# Project  : Cedar Backup, release 3
# Purpose  : Provides location to maintain release information.
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

"""
Provides location to maintain version information.

@sort: AUTHOR, EMAIL, COPYRIGHT, VERSION, DATE, URL

@var AUTHOR: Author of software.
@var EMAIL: Email address of author.
@var COPYRIGHT: Copyright date.
@var VERSION: Software version.
@var DATE: Software release date.
@var URL: URL of Cedar Backup webpage.

@author: Kenneth J. Pronovici <pronovic@ieee.org>
"""

AUTHOR      = "Kenneth J. Pronovici"
EMAIL       = "pronovic@ieee.org"
COPYRIGHT   = "2004-2011,2013-2015"
VERSION     = "3.1.1"
DATE        = "04 Aug 2015"
URL         = "https://bitbucket.org/cedarsolutions/cedar-backup3"

